@@ -2,17 +2,13 @@
 #define _DACT_H
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 4
-#define DACT_VER_REVISION 1
-
-#ifndef DACT_BLK_SIZE
-#define DACT_BLK_SIZE 1024
-#endif
-
+#define DACT_VER_REVISION 6
 
 #define DACT_MODE_COMPR 1
 #define DACT_MODE_DECMP 2
 #define DACT_MODE_STAT  3
 
+#define MAX_DACT_BLK_SIZE 16384
 
 #if defined(__WIN32__) || defined(GO32)
 #ifndef TWO_BYTES
@@ -31,6 +27,9 @@
 #endif
 #endif
 
+#define DACT_MAGIC_NUMBER 0x44414354
+#define DACT_MAGIC_OFFSET 3
+#define DACT_MAGIC_SIZE   4
 
 
 struct dact_header {
@@ -41,4 +40,9 @@ struct dact_header {
 	TWO_BYTES	size;
 	unsigned char	algo;
 };
+#ifdef __DACT_C
+TWO_BYTES DACT_BLK_SIZE=4088;
+#else
+extern TWO_BYTES DACT_BLK_SIZE;
+#endif
 #endif
